@@ -139,19 +139,7 @@ from tifffile import (FileHandle, memmap, decode_lzw, lazyattr, repeat_nd,
                       product, stripnull, format_size, squeeze_axes,
                       create_output)
 
-try:
-    if __package__:
-        from . import _czifile
-    else:
-        import _czifile
-except ImportError as e:
-    jsmessage = "[JS] Exception details: {0} ".format(str(e))
-    warnings.warn(
-        jsmessage +
-        "ImportError: No module named '_czifile'. "
-        "Decoding of JXR and JPEG encoded images will not be available. "
-        "Czifile.pyx can be obtained at http://www.lfd.uci.edu/~gohlke/")
-    _czifile = None
+_czifile = None
 
 __version__ = '2017.09.12'
 __docformat__ = 'restructuredtext en'
